@@ -129,7 +129,7 @@ class Drush:
 
             return sp.check_call(command_line, stdout=self._stdout)
 
-    def init_dir(self, major_version=7, minor_version=23, cache=True):
+    def init_dir(self, major_version=7, minor_version=24, cache=True):
         """Initialises a Drupal root with a version specified.
 
         Kwargs:
@@ -263,6 +263,16 @@ class Drush:
         """
         return self.command('en -y %s' % (module_name))
 
+
+    def dis(self, module_name):
+        """Disable module front-end method.
+
+        Arguments:
+        module_name -- str, system module name
+        """
+        self.command('dis -y %s' % (module_name))
+
+
     def install_lib(self, library_name, stdout=None):
         """Installs a library into sites/all/libraries (usually).
 
